==> mobiusft-0.5.26.zip: mobiusft-0.5.26/src/mobius/regex_impl.h <==
#ifndef __MOBIUS_REGEX_H__
#define __MOBIUS_REGEX_H__

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <regex.h>
#include <string>
#include <vector>

namespace mobius
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief regular expression implementation
//! \author Eduardo Aguiar
// Using POSIX regex until GCC's C++11 <regex> implementation is widely available.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class regex
{
private:
  using size_type = std::vector <std::string>::size_type;
  std::vector <std::string> matches_;
  regex_t reg_;

public:
  regex (const std::string&, int = REG_EXTENDED);
  regex (const regex&) = default;
  regex (regex&&) = default;
  regex& operator= (const regex&) = default;
  regex& operator= (regex&&) = default;
  ~regex ();

  bool match (const std::string&);
  const std::string operator[](size_type) const;

  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
  //! \brief get number of groups of expression
  //! \return number of groups
  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
  size_type
  size () const
  {
    return matches_.size ();
  }
};

} // namespace mobius

#endif

==> mobiusft-1.11.zip: mobiusft-1.11/src/mobius/regex_impl.h <==
#ifndef MOBIUS_REGEX_H
#define MOBIUS_REGEX_H

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <regex.h>
#include <string>
#include <vector>

namespace mobius
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief regular expression implementation
//! \author Eduardo Aguiar
// Using POSIX regex until GCC's C++11 <regex> implementation is widely available.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class regex
{
private:
  using size_type = std::vector <std::string>::size_type;
  std::vector <std::string> matches_;
  regex_t reg_;

public:
  regex (const std::string&, int = REG_EXTENDED);
  regex (const regex&) = default;
  regex (regex&&) = default;
  regex& operator= (const regex&) = default;
  regex& operator= (regex&&) = default;
  ~regex ();

  bool match (const std::string&);
  std::string operator[](size_type) const;

  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
  //! \brief get number of groups of expression
  //! \return number of groups
  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
  size_type
  size () const
  {
    return matches_.size ();
  }
};

} // namespace mobius

#endif
